@@ -1,16 +1,21 @@
-// functions already exported by bindgen : 0
-// -----------------------------------------
-//
-// static inline functions total: 1
-// ------------------------------------------ (done / remaining)
+//! `NcInput`
+
+// functions manually reimplemented: 1
+// ------------------------------------------
 // (+) done: 1 / 0
 // (#) test: 0 / 1
 // ------------------------------------------
-//+ ncinput_equal_p
+// + ncinput_equal_p
 
-use crate::types::NcInput;
+/// Reads and decodes input events
+///
+/// Reads from stdin and decodes the input to stdout,
+/// including synthesized events and mouse events.
+///
+/// To exit, generate EOF (usually Ctrl+‘d’).
+pub type NcInput = crate::bindings::ffi::ncinput;
 
-/// Compare two ncinput structs for data equality by doing a field-by-field
+/// Compares two ncinput structs for data equality by doing a field-by-field
 /// comparison for equality (excepting seqnum).
 ///
 /// Returns true if the two are data-equivalent.
@@ -25,6 +30,7 @@ pub fn ncinput_equal_p(n1: NcInput, n2: NcInput) -> bool {
     true
 }
 
+/// New `NcInput`.
 impl NcInput {
     pub fn new() -> NcInput {
         NcInput {
@@ -38,17 +44,3 @@ impl NcInput {
         }
     }
 }
-
-/*
-#[cfg(test)]
-mod test {
-    use super::nc;
-    use serial_test::serial;
-
-    #[test]
-    #[serial]
-    fn ncinput_equal_p() {
-        assert!();
-    }
-}
-*/
