@@ -587,7 +587,7 @@ int main(int argc, char** argv){
     if(hud_destroy()){ // destroy here since notcurses_drop_planes will kill it
       goto err;
     }
-    if(fpsgraph_stop(nc)){
+    if(fpsgraph_stop()){
       goto err;
     }
     about_destroy(nc);
