@@ -126,13 +126,13 @@ draw_eagle(struct ncplane* n, const char* sprite){
       case '0':
         break;
       case '1':
-        ncplane_set_fg_rgb8(n, 0xff, 0xff, 0xff);
+        ncplane_set_fg_rgb8(n, 0xfc, 0xfc, 0xfc);
         break;
       case '2':
-        ncplane_set_fg_rgb8(n, 0xe3, 0x9d, 0x25);
+        ncplane_set_fg_rgb8(n, 0xbc, 0xbc, 0xbc);
         break;
       case '3':
-        ncplane_set_fg_rgb8(n, 0x3a, 0x84, 0x00);
+        ncplane_set_fg_rgb8(n, 0x00, 0x00, 0x00);
         break;
     }
     if(sprite[s] != '0'){
