@@ -26,6 +26,8 @@ static int plot_grab_y = -1;
 // position of the plot *when grab started*
 static int plot_pos_y;
 
+#define FPSHZ 10
+
 // how many columns for runtime?
 #define HUD_ROWS (3 + 2) // 2 for borders
 static const int HUD_COLS = 23 + 2; // 2 for borders
@@ -97,7 +99,8 @@ debug_toggle(struct notcurses* nc){
     .y = 3,
     .x = NCALIGN_CENTER,
     .rows = count_debug_lines(output, outputlen) + 1,
-    .cols = dimx + 1, // so we don't break lines before the true boundary
+    // 1 plus the max len of debug output so it can print against right border
+    .cols = 81,
     .flags = NCPLANE_OPTION_HORALIGNED,
   };
   struct ncplane* n = ncplane_create(notcurses_stdplane(nc), &nopts);
@@ -112,7 +115,7 @@ debug_toggle(struct notcurses* nc){
   ncplane_set_scrolling(n, true);
   ncplane_set_fg_rgb(n, 0x0a0a0a);
   ncplane_set_bg_rgb(n, 0xffffe5);
-  if(ncplane_puttext(n, 0, NCALIGN_CENTER, output, &outputlen) < 0){
+  if(ncplane_puttext(n, 0, NCALIGN_LEFT, output, &outputlen) < 0){
     free(output);
     ncplane_destroy(n);
     return;
@@ -502,7 +505,7 @@ int hud_schedule(const char* demoname){
   return hud_print_finished(elems);
 }
 
-// wake up every 100ms and render a frame so the HUD doesn't appear locked up.
+// wake up every 10ms and render a frame so the HUD doesn't appear locked up.
 // provide an absolute deadline calculated via CLOCK_MONOTONIC.
 static int
 demo_nanosleep_abstime_ns(struct notcurses* nc, uint64_t deadline){
@@ -512,8 +515,8 @@ demo_nanosleep_abstime_ns(struct notcurses* nc, uint64_t deadline){
   clock_gettime(CLOCK_MONOTONIC, &now);
   while(deadline > timespec_to_ns(&now)){
     fsleep.tv_sec = 0;
-    fsleep.tv_nsec = GIG / 10;
-    if(deadline - timespec_to_ns(&now) < GIG / 10){
+    fsleep.tv_nsec = MAXSLEEP;
+    if(deadline - timespec_to_ns(&now) < GIG / 100){
       fsleep.tv_nsec = deadline - timespec_to_ns(&now);
     }
     ncinput ni;
@@ -562,7 +565,7 @@ int demo_render(struct notcurses* nc){
     if(!plot_hidden){
       ncplane_move_top(ncuplot_plane(plot));
     }
-    uint64_t ns = (timespec_to_ns(&ts) - plottimestart) / GIG;
+    uint64_t ns = (timespec_to_ns(&ts) - plottimestart) / (GIG / FPSHZ);
     ncuplot_add_sample(plot, ns, 1);
   }
   if(menu){
@@ -634,9 +637,12 @@ int fpsgraph_init(struct notcurses* nc){
   ncplane_set_base(newp, "", style, channels);
   ncplot_options opts;
   memset(&opts, 0, sizeof(opts));
-  opts.flags = NCPLOT_OPTION_LABELTICKSD | NCPLOT_OPTION_EXPONENTIALD;
-  opts.legendstyle = NCSTYLE_ITALIC;
-  opts.title = "frames per second";
+  opts.flags = NCPLOT_OPTION_LABELTICKSD |
+               NCPLOT_OPTION_EXPONENTIALD |
+               NCPLOT_OPTION_PRINTSAMPLE;
+  opts.gridtype = NCBLIT_BRAILLE;
+  opts.legendstyle = NCSTYLE_ITALIC | NCSTYLE_BOLD;
+  opts.title = "frames per decisecond";
   channels_set_fg_rgb8(&opts.minchannels, 0x80, 0x80, 0xff);
   channels_set_bg_rgb(&opts.minchannels, 0x201020);
   channels_set_bg_alpha(&opts.minchannels, CELL_ALPHA_BLEND);
@@ -658,11 +664,10 @@ int fpsgraph_init(struct notcurses* nc){
   return 0;
 }
 
-int fpsgraph_stop(struct notcurses* nc){
+int fpsgraph_stop(void){
   if(plot){
     ncuplot_destroy(plot);
     plot = NULL;
-    notcurses_render(nc);
   }
   return 0;
 }
