@@ -502,8 +502,6 @@ inline int ncplane_cursor_move_yx(ncplane* n, int y, int x){
 ncplane* ncplane_dup(const ncplane* n, void* opaque){
   int dimy = n->leny;
   int dimx = n->lenx;
-  uint16_t attr = ncplane_styles(n);
-  uint64_t chan = ncplane_channels(n);
   // if we're duping the standard plane, we need adjust for marginalia
   const struct notcurses* nc = ncplane_notcurses_const(n);
   const int placey = n->absy - nc->margin_t;
@@ -515,6 +513,8 @@ ncplane* ncplane_dup(const ncplane* n, void* opaque){
     .cols = dimx,
     .userptr = opaque,
     .name = n->name,
+    .resizecb = ncplane_resizecb(n),
+    .flags = 0,
   };
   ncplane* newn = ncplane_create(n->boundto, &nopts);
   if(newn){
@@ -526,8 +526,9 @@ ncplane* ncplane_dup(const ncplane* n, void* opaque){
         ncplane_destroy(newn);
         return NULL;
       }
-      newn->stylemask = attr;
-      newn->channels = chan;
+      newn->align = n->align;
+      newn->stylemask = ncplane_styles(n);
+      newn->channels = ncplane_channels(n);
       memmove(newn->fb, n->fb, sizeof(*n->fb) * dimx * dimy);
       // we dupd the egcpool, so just dup the goffset
       newn->basecell = n->basecell;
@@ -1061,7 +1062,8 @@ notcurses* notcurses_init(const notcurses_options* opts, FILE* outfp){
   if(setup_signals(ret,
                    (opts->flags & NCOPTION_NO_QUIT_SIGHANDLERS),
                    (opts->flags & NCOPTION_NO_WINCH_SIGHANDLER))){
-    goto err;
+    // don't treat failure here as an error. it screws up unit tests, and one
+    // day we'll need support multiple notcurses contexts. FIXME
   }
   int termerr;
   if(setupterm(opts->termtype, ret->ttyfd, &termerr) != OK){
@@ -1512,7 +1514,8 @@ ncplane_put(ncplane* n, int y, int x, const char* egc, int cols,
   if(ncplane_cursor_move_yx(n, y, x)){
     return -1;
   }
-  // FIXME don't we need to check here for wide character on edge?
+  // FIXME don't we need to check here for wide character on edge (though our
+  // docs currently claim that a wide char on edge is allowed...)?
   if(*egc == '\n'){
     if(n->scrolling){
       scroll_down(n);
@@ -1569,6 +1572,7 @@ int ncplane_putegc_yx(ncplane* n, int y, int x, const char* gclust, int* sbytes)
   if(sbytes){
     *sbytes = bytes;
   }
+//fprintf(stderr, "cols: %d wcs: %d\n", cols, bytes);
   return ncplane_put(n, y, x, gclust, cols, n->stylemask, n->channels, bytes);
 }
 
@@ -2035,6 +2039,14 @@ ncplane* notcurses_bottom(notcurses* n){
   return ncplane_pile(n->stdplane)->bottom;
 }
 
+ncplane* ncpile_top(ncplane* n){
+  return ncplane_pile(n)->top;
+}
+
+ncplane* ncpile_bottom(ncplane* n){
+  return ncplane_pile(n)->bottom;
+}
+
 ncplane* ncplane_below(ncplane* n){
   return n->below;
 }
@@ -2167,6 +2179,9 @@ const ncplane* ncplane_parent_const(const ncplane* n){
 }
 
 void ncplane_set_resizecb(ncplane* n, int(*resizecb)(ncplane*)){
+  if(n == notcurses_stdplane(ncplane_notcurses(n))){
+    return;
+  }
   n->resizecb = resizecb;
 }
 
