@@ -13,25 +13,22 @@ class ncppplot {
  public:
 
  // these were all originally plain C, sorry for the non-idiomatic usage FIXME
- // ought admit nullptr opts FIXME
- // reenable logging once #703 is done
  static bool create(ncppplot<T>* ncpp, ncplane* n, const ncplot_options* opts, T miny, T maxy) {
    ncplot_options zeroed = {};
    if(!opts){
      opts = &zeroed;
    }
-   if(opts->flags > NCPLOT_OPTION_DETECTMAXONLY){
+   if(opts->flags > NCPLOT_OPTION_PRINTSAMPLE){
      logwarn(ncplane_notcurses(n), "Provided unsupported flags %016jx\n", (uintmax_t)opts->flags);
    }
-   //struct notcurses* nc = n->nc;
+   auto nc = ncplane_notcurses(n);
    // if miny == maxy (enabling domain detection), they both must be equal to 0
    if(miny == maxy && miny){
-     //logerror(nc, "Supplied non-zero domain detection param %d\n", miny);
      ncplane_destroy(n);
      return false;
    }
    if(opts->rangex < 0){
-     //logerror(nc, "Supplied negative independent range %d\n", opts->rangex);
+     logerror(nc, "Supplied negative independent range %d\n", opts->rangex);
      ncplane_destroy(n);
      return false;
    }
@@ -41,7 +38,7 @@ class ncppplot {
    }
    // DETECTMAXONLY can't be used without domain detection
    if(opts->flags & NCPLOT_OPTION_DETECTMAXONLY && (miny != maxy)){
-     //logerror(nc, "Supplied DETECTMAXONLY without domain detection");
+     logerror(nc, "Supplied DETECTMAXONLY without domain detection");
      ncplane_destroy(n);
      return false;
    }
@@ -105,6 +102,7 @@ class ncppplot {
    ncpp->vertical_indep = opts->flags & NCPLOT_OPTION_VERTICALI;
    ncpp->exponentiali = opts->flags & NCPLOT_OPTION_EXPONENTIALD;
    ncpp->detectonlymax = opts->flags & NCPLOT_OPTION_DETECTMAXONLY;
+   ncpp->printsample = opts->flags & NCPLOT_OPTION_PRINTSAMPLE;
    if( (ncpp->detectdomain = (miny == maxy)) ){
      ncpp->maxy = 0;
      ncpp->miny = std::numeric_limits<T>::max();
@@ -171,11 +169,11 @@ class ncppplot {
        }
      }
    }else if(!title.empty()){
-      uint64_t channels = 0;
-      calc_gradient_channels(&channels, minchannels, minchannels,
-                             maxchannels, maxchannels, dimy - 1, 0, dimy, dimx);
-      ncplane_set_channels(ncp, channels);
-      ncplane_printf_yx(ncp, 0, PREFIXCOLUMNS - title.length(), "%s", title.c_str());
+     uint64_t channels = 0;
+     calc_gradient_channels(&channels, minchannels, minchannels,
+                            maxchannels, maxchannels, dimy - 1, 0, dimy, dimx);
+     ncplane_set_channels(ncp, channels);
+     ncplane_printf_yx(ncp, 0, PREFIXCOLUMNS - title.length(), "%s", title.c_str());
    }
    ncplane_set_styles(ncp, NCSTYLE_NONE);
    if(finalx < startx){ // exit on pathologically narrow planes
@@ -207,8 +205,9 @@ class ncppplot {
      // starting from the least-significant row, progress in the more significant
      // direction, drawing egcs from the grid specification, aborting early if
      // we can't draw anything in a given cell.
-     double intervalbase = miny;
+     T intervalbase = miny;
      const wchar_t* egc = bset->egcs;
+     bool done = !bset->fill;
      for(int y = 0 ; y < dimy ; ++y){
        uint64_t channels = 0;
        calc_gradient_channels(&channels, minchannels, minchannels,
@@ -218,7 +217,6 @@ class ncppplot {
        // if we've got at least one interval's worth on the number of positions
        // times the number of intervals per position plus the starting offset,
        // we're going to print *something*
-       bool done = !bset->fill;
        for(int i = 0 ; i < scale ; ++i){
          sumidx *= states;
          if(intervalbase < gvals[i]){
@@ -227,11 +225,9 @@ class ncppplot {
              double scaled = log(gvals[i] - miny) / log(interval);
              double sival = intervalbase ? log(intervalbase) / log(interval) : 0;
              egcidx = scaled - sival;
-//fprintf(stderr, "egcidx: %zu gvals: %u interval: %f scaled: %f sival: %f\n", egcidx, gvals[i], interval, scaled, sival);
            }else{
              egcidx = (gvals[i] - intervalbase) / interval;
            }
-//fprintf(stderr, "%d/%d ibase: %f ival: %f egcidx: %zu\n", dimy - y - 1, x, intervalbase, interval, egcidx);
            if(egcidx >= states){
              egcidx = states - 1;
              done = false;
@@ -240,14 +236,27 @@ class ncppplot {
          }else{
            egcidx = 0;
          }
+//fprintf(stderr, "y: %d i(scale): %d gvals[%d]: %ju egcidx: %zu sumidx: %zu interval: %f intervalbase: %ju\n", y, i, i, gvals[i], egcidx, sumidx, interval, intervalbase);
        }
        // if we're not UTF8, we can only arrive here via NCBLIT_1x1 (otherwise
        // we would have errored out during construction). even then, however,
        // we need handle ASCII differently, since it can't print full block.
-       // in ASCII mode, egcidx != means swap colors and use space.
+       // in ASCII mode, sumidx != 0 means swap colors and use space. in all
+       // modes, sumidx == 0 means don't do shit, since we erased earlier.
+//if(sumidx)fprintf(stderr, "dimy: %d y: %d x: %d sumidx: %zu egc[%zu]: %lc\n", dimy, y, x, sumidx, sumidx, egc[sumidx]);
        if(sumidx){
          if(notcurses_canutf8(ncplane_notcurses(ncp))){
-           if(ncplane_putwc_yx(ncp, dimy - y - 1, x, egc[sumidx]) <= 0){
+           char utf8[MB_CUR_MAX + 1];
+           int bytes = wctomb(utf8, egc[sumidx]);
+           if(bytes < 0){
+             return -1;
+           }
+           utf8[bytes] = '\0';
+           cell* c = ncplane_cell_ref_yx(ncp, dimy - y - 1, x);
+           cell_set_bchannel(c, channels_bchannel(channels));
+           cell_set_fchannel(c, channels_fchannel(channels));
+           cell_set_styles(c, NCSTYLE_NONE);
+           if(pool_blit_direct(&ncp->pool, c, utf8, bytes, 1) <= 0){
              return -1;
            }
          }else{
@@ -274,6 +283,11 @@ class ncppplot {
        }
      }
    }
+   if(printsample){
+     int lastslot = slotstart ? slotstart - 1 : slotcount - 1;
+     ncplane_set_styles(ncp, legendstyle);
+     ncplane_printf_aligned(ncp, dimy - 1, NCALIGN_RIGHT, "%ju", (uintmax_t)slots[lastslot]);
+   }
    ncplane_home(ncp);
    return 0;
  }
@@ -413,6 +427,7 @@ class ncppplot {
  bool exponentiali; // exponential independent axis
  bool detectdomain;   // is domain detection in effect (stretch the domain)?
  bool detectonlymax;  // domain detection applies only to max, not min
+ bool printsample; // print the most recent sample
 
 };
 
