@@ -261,7 +261,7 @@ paint(const ncplane* p, struct crender* rvec, int dstleny, int dstlenx,
       const cell* vis = &p->fb[nfbcellidx(p, y, x)];
       // if we never loaded any content into the cell (or obliterated it by
       // writing in a zero), use the plane's base cell.
-      if(vis->gcluster == 0 && !cell_wide_right_p(vis)){
+      if(vis->gcluster == 0 && !cell_double_wide_p(vis)){
         vis = &p->basecell;
       }
       // if we have no character in this cell, we continue to look for a
@@ -278,11 +278,11 @@ paint(const ncplane* p, struct crender* rvec, int dstleny, int dstlenx,
           if(cell_double_wide_p(vis)){
             // are we on the last column of the real screen? if so, 0x20 us
             if(absx >= dstlenx - 1){
-              targc->gcluster = ' ';
+              targc->gcluster = htole(' ');
             // is the next cell occupied? if so, 0x20 us
             }else if(crender[1].c.gcluster){
 //fprintf(stderr, "NULLING out %d/%d (%d/%d) due to %u\n", y, x, absy, absx, crender[1].c.gcluster);
-              targc->gcluster = ' ';
+              targc->gcluster = htole(' ');
             }else{
               cell_set_wide(targc);
               targc->stylemask = vis->stylemask;
@@ -395,8 +395,7 @@ postpaint(cell* lastframe, int dimy, int dimx, struct crender* rvec, egcpool* po
       cell* targc = &crender->c;
       lock_in_highcontrast(targc, crender);
       cell* prevcell = &lastframe[fbcellidx(y, dimx, x)];
-//fprintf(stderr, "WROTE %u [%s] to %d/%d\n", targc->gcluster, cell_extended_gcluster(crender->p, targc), y, x);
-      if(cellcmp_and_dupfar(pool, prevcell, crender->p, targc)){
+      if(cellcmp_and_dupfar(pool, prevcell, crender->p, targc) > 0){
         crender->damaged = true;
         if(cell_wide_left_p(targc)){
           const ncplane* tmpp = crender->p;
@@ -408,7 +407,7 @@ postpaint(cell* lastframe, int dimy, int dimx, struct crender* rvec, egcpool* po
           targc->gcluster = 0;
           targc->channels = crender[-1].c.channels;
           targc->stylemask = crender[-1].c.stylemask;
-          if(cellcmp_and_dupfar(pool, prevcell, crender->p, targc)){
+          if(cellcmp_and_dupfar(pool, prevcell, crender->p, targc) > 0){
             crender->damaged = true;
           }
         }
@@ -500,8 +499,8 @@ static int
 term_putc(FILE* out, const egcpool* e, const cell* c){
   if(cell_simple_p(c)){
 //fprintf(stderr, "[%.4s] %08x\n", (const char*)&c->gcluster, c->gcluster); }
-    // FIXME pretty sure we need 0xff000000llu + 24-rshift on big-endian, fuck
-    if(c->gcluster == 0 || iscntrl(c->gcluster & 0xffu)){
+    uint32_t firstbyte = htole(c->gcluster) & 0xff;
+    if(c->gcluster == 0 || iscntrl(firstbyte)){
       if(ncfputc(' ', out) == EOF){
         return -1;
       }
