@@ -44,7 +44,7 @@ TEST_CASE("Cell") {
 
   SUBCASE("MultibyteWidth") {
     CHECK(0 == ncstrwidth(""));       // zero bytes, zero columns
-    CHECK(0 == ncstrwidth("\x7"));   // single byte, non-printable
+    CHECK(-1 == ncstrwidth("\x7"));   // single byte, non-printable
     CHECK(1 == ncstrwidth(" "));      // single byte, one column
     CHECK(5 == ncstrwidth("abcde"));  // single byte, one column
     CHECK(1 == ncstrwidth("µ"));      // two bytes, one column
@@ -344,6 +344,35 @@ TEST_CASE("Cell") {
     free(egc);
   }
 
+  SUBCASE("CellLoadCharPrinting") {
+    cell c = CELL_TRIVIAL_INITIALIZER;
+    CHECK(1 == cell_load_char(n_, &c, '*'));
+    CHECK(0 == strcmp(cell_extended_gcluster(n_, &c), "*"));
+  }
+
+  SUBCASE("CellLoadCharWhitespace") {
+    cell c = CELL_TRIVIAL_INITIALIZER;
+    CHECK(1 == cell_load_char(n_, &c, '\f'));
+    CHECK(1 == cell_load_char(n_, &c, '\n'));
+    CHECK(1 == cell_load_char(n_, &c, '\t'));
+    CHECK(1 == cell_load_char(n_, &c, ' '));
+  }
+
+  SUBCASE("CellLoadCharControl") {
+    cell c = CELL_TRIVIAL_INITIALIZER;
+    CHECK(0 == cell_load_char(n_, &c, '\0'));
+    CHECK(-1 == cell_load_char(n_, &c, 1));
+    CHECK(-1 == cell_load_char(n_, &c, '\b'));
+  }
+
+  SUBCASE("CellLoadEGC32") {
+    cell c = CELL_TRIVIAL_INITIALIZER;
+    CHECK(0 == cell_load_egc32(n_, &c, 0));
+    CHECK(1 == cell_load_egc32(n_, &c, 0x65));   // U+0061 LATIN SMALL LETTER A
+    CHECK(2 == cell_load_egc32(n_, &c, 0xb5c2)); // U+00B5 MICRO SIGN
+    CHECK(4 == cell_load_egc32(n_, &c, 0x82a69ff0)); // U+1F982 SCORPION
+  }
+
   // common teardown
   CHECK(0 == notcurses_stop(nc_));
 }
